@@ -1,28 +1,21 @@
-#[cfg(any(feature = "py", feature = "rs"))]
+
 use crate::utils::{
     cal3BV, cal3BV_exp, cal_table_minenum_enum, cal_table_minenum_recursion, combine, enuOneStep,
-    enum_comb, layMineOpNumber, lay_mine_number, legalize_board, refreshBoard, refresh_matrix,
+    enum_comb, lay_mine_op_number, lay_mine_number, legalize_board, refreshBoard, refresh_matrix,
     refresh_matrixs, sum, unsolvableStructure, BigNumber, C_query, C,
 };
 
-#[cfg(feature = "js")]
-use crate::utils::{
-    cal3BV, cal3BV_exp, cal_table_minenum_enum, cal_table_minenum_recursion, combine, enuOneStep,
-    enum_comb, layMineOpNumber, lay_mine_number, legalize_board, refreshBoard, refresh_matrix,
-    refresh_matrixs, sum, unsolvableStructure, BigNumber, C_query, C,
-};
 
 #[cfg(any(feature = "py", feature = "rs"))]
 use crate::OBR::ImageBoard;
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
 use itertools::Itertools;
 
 #[cfg(any(feature = "py", feature = "rs"))]
 use rand::seq::SliceRandom;
-
 #[cfg(any(feature = "py", feature = "rs"))]
 use rand::thread_rng;
+
 use std::cmp::{max, min};
 use std::sync::mpsc;
 use std::sync::{Arc, Mutex};
@@ -35,15 +28,15 @@ use tract_ndarray::Array;
 use tract_onnx::prelude::*;
 
 // 中高级的算法，例如无猜埋雷、判雷引擎、计算概率
-// 文件结构是algorithms单方面引用utils，但暂时把所有文件写在同一个目录内，以后分开
 
+
+/// 双集合判雷引擎，除判雷外，会在局面上标是雷（11），但不标非雷（12）
 pub fn SolveMinus(
     MatrixA: &Vec<Vec<i32>>,
     Matrixx: &Vec<(usize, usize)>,
     Matrixb: &Vec<i32>,
     BoardofGame: &mut Vec<Vec<i32>>,
 ) -> (Vec<(usize, usize)>, bool) {
-    // 双集合判雷引擎，除判雷外，会在局面上标是雷（11），但不标非雷（12）
     let mut flag = false;
     let mut NotMine = vec![];
     let mut NotMineRel = vec![];
@@ -95,6 +88,7 @@ pub fn SolveMinus(
     (NotMine, flag)
 }
 
+/// 单集合判雷引擎，除判雷外，会在局面上标是雷（11），但不标非雷（12）
 #[cfg(any(feature = "py", feature = "js", feature = "rs"))]
 pub fn SolveDirect(
     MatrixA: &mut Vec<Vec<i32>>,
@@ -102,8 +96,7 @@ pub fn SolveDirect(
     Matrixb: &mut Vec<i32>,
     BoardofGame: &mut Vec<Vec<i32>>,
 ) -> (Vec<(usize, usize)>, bool) {
-    // 单集合判雷引擎，除判雷外，会在局面上标是雷（11），但不标非雷（12）
-    // 这三个矩阵算完就费了比较可惜，待优化
+    // 这三个矩阵被消费掉了比较可惜，待优化
     let mut flag = false;
     let mut NotMine = vec![];
     let mut MatrixColumn = Matrixx.len();
@@ -148,17 +141,16 @@ pub fn SolveDirect(
     (NotMine, flag)
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 输入局面、未被标出的雷数
+/// 局面中可以标雷（11），但必须全部标对
+/// 未知雷数 = 总雷数 - 已经标出的雷
+/// 若超出枚举长度，返回空向量
+/// 返回所有边缘格子是雷的概率、内部未知格子是雷的概率、局面中总未知雷数的范围
+/// 若没有内部未知区域，返回NaN
 pub fn cal_possibility(
     board_of_game: &Vec<Vec<i32>>,
     mut mine_num: f64,
 ) -> Result<(Vec<((usize, usize), f64)>, f64, [usize; 3]), usize> {
-    // 输入局面、未被标出的雷数，返回每一个未知的格子是雷的概率
-    // 局面中可以标雷，但必须全部标对
-    // 未知雷数为总雷数减去已经标出的雷
-    // 若超出枚举长度，那些格子的概率不予返回
-    // 输出所有边缘格子是雷的概率和内部未知格子是雷的概率
-    // 若没有内部未知区域，返回NaN
     let mut p = vec![];
     let mut table_cell_minenum_s: Vec<Vec<Vec<usize>>> = vec![];
     // 每块每格雷数表：记录了每块每格（或者地位等同的复合格）、每种总雷数下的是雷情况数
@@ -345,7 +337,7 @@ pub fn cal_possibility(
     ))
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 计算局面中各位置是雷的概率，按照所在的位置返回
 pub fn cal_possibility_onboard(
     board_of_game: &Vec<Vec<i32>>,
     mine_num: f64,
@@ -373,13 +365,28 @@ pub fn cal_possibility_onboard(
     Ok((p, pp.2))
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 计算单点开空概率
+/// 输入局面、未被标出的雷数、坐标
+/// 返回坐标处开空的概率
+/// ```
+/// let game_board = vec![
+///     vec![10, 10,  1,  1, 10,  1,  0,  0],
+///     vec![10, 10,  1, 10, 10,  3,  2,  1],
+///     vec![10, 10, 10, 10, 10, 10, 10, 10],
+///     vec![10, 10, 10, 10, 10, 10, 10, 10],
+///     vec![10, 10, 10, 10, 10, 10, 10, 10],
+///     vec![10, 10, 10, 10,  2, 10, 10, 10],
+///     vec![10, 10, 10, 10, 10, 10, 10, 10],
+///     vec![10, 10, 10, 10, 10, 10, 10, 10],
+/// ];
+/// let ans = cal_is_op_possibility_cells(&game_board, 20.0, &vec![[0, 0], [1, 1], [1, 6], [7, 2]]);
+/// print!("{:?}", ans)
+/// ```
 pub fn cal_is_op_possibility_cells(
     board_of_game: &Vec<Vec<i32>>,
     mine_num: f64,
     cells: &Vec<[usize; 2]>,
 ) -> Vec<f64> {
-    // 计算开空概率
     let mut poss = vec![1.0; cells.len()];
     let row = board_of_game.len();
     let column = board_of_game[0].len();
@@ -412,7 +419,12 @@ pub fn cal_is_op_possibility_cells(
     poss
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 埋雷，使得起手位置必为空
+/// 输入行数、列数、雷数、起手位置行数、起手位置列数、最小3BV、最大3BV、最大尝试次数、模式（保留）
+/// 输出局面和参数，分别为：是否满足3BV上下限、3BV、尝试次数
+/// ```
+/// layMineOp(16, 30, 99, 0, 0, 100, 381, 10000, 0)
+/// ```
 pub fn layMineOp(
     row: usize,
     column: usize,
@@ -429,7 +441,7 @@ pub fn layMineOp(
     let mut Num3BV = 0;
     let mut Board = vec![vec![0; column]; row];
     while times < MaxTimes {
-        Board = layMineOpNumber(row, column, MineNum, x0, y0);
+        Board = lay_mine_op_number(row, column, MineNum, x0, y0);
         times += 1;
         let mut Num3BV = cal3BV(&Board);
         if Num3BV >= Min3BV && Num3BV <= Max3BV {
@@ -445,7 +457,10 @@ pub fn layMineOp(
     (Board, Parameters)
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 枚举法判雷引擎
+/// 输入分块好的矩阵、局面、枚举长度限制
+/// 输出不是雷的位置
+/// 注意，不修改输入进来的局面，即不帮助标雷
 pub fn SolveEnumerate(
     matrix_as: &Vec<Vec<Vec<i32>>>,
     matrix_xs: &Vec<Vec<(usize, usize)>>,
@@ -453,9 +468,6 @@ pub fn SolveEnumerate(
     board_of_game: &Vec<Vec<i32>>,
     enuLimit: usize,
 ) -> (Vec<(usize, usize)>, bool) {
-    // 枚举法判雷引擎
-    // 输入的矩阵都是分块好的
-    // 只判断哪些不是雷，不判断哪些是雷，不修改输入进来的局面（不帮助标雷）
     // print!("matrix_xs: {:?}", matrix_xs);
     // print!("matrix_as: {:?}", matrix_as);
     // print!("matrix_bs: {:?}", matrix_bs);
@@ -504,10 +516,10 @@ pub fn SolveEnumerate(
     (NotMine, flag)
 }
 
+// 判断当前是否获胜
+// 游戏局面中必须没有标错的雷
+// 这个函数不具备普遍意义
 fn isVictory(BoardofGame: &Vec<Vec<i32>>, Board: &Vec<Vec<i32>>) -> bool {
-    // 判断当前是否获胜
-    // 游戏局面中必须没有标错的雷
-    // 这个函数不具备普遍意义
     let row = BoardofGame.len();
     let Col = BoardofGame[0].len();
     for i in 0..row {
@@ -520,10 +532,9 @@ fn isVictory(BoardofGame: &Vec<Vec<i32>>, Board: &Vec<Vec<i32>>) -> bool {
     return true;
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
+/// 从指定位置开始扫，判断局面是否无猜
+/// 注意：周围一圈都是雷，那么若中间是雷不算猜，若中间不是雷算猜
 pub fn isSolvable(Board: &Vec<Vec<i32>>, x0: usize, y0: usize, enuLimit: usize) -> bool {
-    // 从指定位置开始扫，判断局面是否无猜
-    // 周围一圈都是雷，那么中间是雷不算猜，中间不是雷算猜
     if unsolvableStructure(&Board) {
         //若包含不可判雷结构，则不是无猜
         return false;
@@ -574,7 +585,6 @@ pub fn isSolvable(Board: &Vec<Vec<i32>>, x0: usize, y0: usize, enuLimit: usize)
     }
 }
 
-#[cfg(any(feature = "py", feature = "rs"))]
 pub fn layMineSolvable_thread(
     row: usize,
     column: usize,
@@ -609,7 +619,7 @@ pub fn layMineSolvable_thread(
                         break;
                     }
                 } // 这块用花括号控制生命周期
-                let Board_ = layMineOpNumber(row, column, MineNum, x0, y0);
+                let Board_ = lay_mine_op_number(row, column, MineNum, x0, y0);
                 counter += 1;
                 if isSolvable(&Board_, x0, y0, enuLimit) {
                     Num3BV = cal3BV(&Board_);
@@ -629,7 +639,7 @@ pub fn layMineSolvable_thread(
                     }
                 }
             }
-            let Board_ = layMineOpNumber(row, column, MineNum, x0, y0);
+            let Board_ = lay_mine_op_number(row, column, MineNum, x0, y0);
             Num3BV = cal3BV(&Board_);
             para[0] = 0;
             para[1] = Num3BV;
@@ -673,7 +683,7 @@ pub fn layMineSolvable(
     let mut Board;
     let mut Num3BV;
     while times < MaxTimes {
-        Board = layMineOpNumber(row, column, MineNum, x0, y0);
+        Board = lay_mine_op_number(row, column, MineNum, x0, y0);
         times += 1;
         if isSolvable(&Board, x0, y0, enuLimit) {
             Num3BV = cal3BV(&Board);
@@ -685,7 +695,7 @@ pub fn layMineSolvable(
             }
         }
     }
-    Board = layMineOpNumber(row, column, MineNum, x0, y0);
+    Board = lay_mine_op_number(row, column, MineNum, x0, y0);
     Num3BV = cal3BV(&Board);
     Parameters.push(0);
     Parameters.push(Num3BV);
