@@ -1,4 +1,3 @@
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
 use itertools::Itertools;
 #[cfg(any(feature = "py", feature = "rs"))]
 use rand::seq::SliceRandom;
@@ -234,7 +233,6 @@ pub fn refresh_matrixs(
     (matrix_as, matrix_xs, matrix_bs, unknow_block, is_mine_num)
 }
 
-#[cfg(any(feature = "py", feature = "rs"))]
 /// 通用标准埋雷引擎，起手位置非类，其余位置的雷服从均匀分布
 /// 输出为二维的局面，其中0代表空，1~8代表1~8，-1代表雷
 pub fn lay_mine_number(
@@ -244,13 +242,18 @@ pub fn lay_mine_number(
     X0: usize,
     Y0: usize,
 ) -> Vec<Vec<i32>> {
-    let mut rng = thread_rng();
     let area: usize = row * column - 1;
     let mut Board1Dim: Vec<i32> = vec![];
     Board1Dim.reserve(area);
     Board1Dim = vec![0; area - MineNum];
     Board1Dim.append(&mut vec![-1; MineNum]);
+
+    #[cfg(any(feature = "py", feature = "rs"))]
+    let mut rng = thread_rng();
+
+    #[cfg(any(feature = "py", feature = "rs"))]
     Board1Dim.shuffle(&mut rng);
+
     let mut Board1Dim_2: Vec<i32> = vec![];
     Board1Dim_2.reserve(area + 1);
     let pointer = X0 + Y0 * row;
@@ -279,15 +282,14 @@ pub fn lay_mine_number(
     Board
 }
 
-#[cfg(any(feature = "py", feature = "rs"))]
-pub fn layMineOpNumber(
+pub fn lay_mine_op_number(
     row: usize,
     column: usize,
     MineNum: usize,
     X0: usize,
     Y0: usize,
 ) -> Vec<Vec<i32>> {
-    let mut rng = thread_rng();
+    
     let mut areaOp = 9;
     if X0 == 0 || Y0 == 0 || X0 == row - 1 || Y0 == column - 1 {
         if X0 == 0 && Y0 == 0
@@ -303,7 +305,12 @@ pub fn layMineOpNumber(
     let area = row * column - areaOp;
     let mut Board1Dim = vec![0; area - MineNum];
     Board1Dim.append(&mut vec![-1; MineNum]);
+
+    #[cfg(any(feature = "py", feature = "rs"))]
+    let mut rng = thread_rng();
+    #[cfg(any(feature = "py", feature = "rs"))]
     Board1Dim.shuffle(&mut rng);
+
     let mut Board = vec![vec![0; column]; row];
     let mut skip = 0;
     for i in 0..(area + areaOp) {
@@ -352,10 +359,12 @@ fn cal3BVonIsland(Board: &Vec<Vec<i32>>) -> usize {
     Num3BVonIsland
 }
 
+/// 计算局面的3BV
 pub fn cal3BV(Board: &Vec<Vec<i32>>) -> usize {
     cal3BVonIsland(&Board) + calOp(Board.clone())
 }
 
+/// 依据左击位置刷新局面
 pub fn refreshBoard(
     Board: &Vec<Vec<i32>>,
     BoardofGame: &mut Vec<Vec<i32>>,
@@ -645,7 +654,6 @@ pub fn enum_comb(
     enum_comb_table
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
 fn enumerateSub(Col: usize, MineNum: usize) -> Vec<Vec<usize>> {
     let mut Out: Vec<Vec<usize>> = vec![];
     for i in (0..Col).combinations(MineNum) {
@@ -658,7 +666,6 @@ fn enumerateSub(Col: usize, MineNum: usize) -> Vec<Vec<usize>> {
     Out
 }
 
-#[cfg(any(feature = "py", feature = "js", feature = "rs"))]
 pub fn enuOneStep(mut AllTable: Vec<Vec<usize>>, TableId: Vec<usize>, b: i32) -> Vec<Vec<usize>> {
     // AllTable不能为空
     let mut NewId: Vec<usize> = vec![];
@@ -976,11 +983,10 @@ pub fn cal_table_minenum_enum(
     Ok((table_minenum, table_cell_minenum))
 }
 
+/// 用几种模板，检测实际局面中是否有明显的死猜的结构。不考虑起手位置，因为起手必开空。
+/// 局面至少大于4*4。
 pub fn unsolvableStructure(BoardCheck: &Vec<Vec<i32>>) -> bool {
-    // 用几种模板，检测局面中是否有明显的死猜的结构
-    // 不考虑起手位置，因为起手必开空
-    // 局面至少大于4*4
-    // 返回0或1
+    
     let row = BoardCheck.len();
     let column = BoardCheck[0].len();
     let mut Board = vec![vec![0; column]; row];
@@ -1200,8 +1206,8 @@ pub fn unsolvableStructure(BoardCheck: &Vec<Vec<i32>>) -> bool {
     false
 }
 
+// 专用于高级局面的3BV快速计算
 pub fn cal3BV_exp(Board: &Vec<Vec<i32>>) -> usize {
-    // 专用于高级局面的3BV快速计算
     let mut board = Board.clone();
     let mut op_id = 0;
     let mut op_list = [false; 200];
@@ -1291,9 +1297,10 @@ pub fn cal3BV_exp(Board: &Vec<Vec<i32>>) -> usize {
     bv
 }
 
+// 把局面合法化：只能合法化简单的情况，不能应付所有的情况！因为检查一个局面是否合法也是NP难的
+// 配合局面光学识别算法
+// 局面中标记的标准是10为待判的雷，1到8，11为已知必然是雷的位置，12是已知必然非雷的位置
 pub fn legalize_board(board: &mut Vec<Vec<i32>>) {
-    // 把局面合法化：只能合法化简单的情况，不能应付所有的情况！因为检查一个局面是否合法也是NP难的
-    // 局面中标记的标准是10为待判的雷，1到8，11为已知必然是雷的位置，12是已知必然非雷的位置
     let row = board.len();
     let column = board[0].len();
     for x in 0..row {
